@@ -1,4 +1,5 @@
 import logging
+import os
 from ipaddress import ip_address, ip_network
 from pathlib import Path
 
@@ -53,7 +54,9 @@ def githookA2HostingCloneUpdate(request):
         call_command('collectstatic', interactive=False)
 
         logger.debug(settings.BASE_DIR)
-        Path(settings.BASE_DIR + "/tmp/restart.txt").touch()
+        full_path_touch = os.path.join(settings.BASE_DIR, "/tmp/restart.txt")
+        logger.debug(full_path_touch)
+        Path(full_path_touch).touch()
 
         return HttpResponse('success')
     # In case we receive an event that's not ping or push
@@ -100,7 +103,9 @@ def githookA2HostingRemoteUpdate(request):
         call_command('collectstatic', interactive=False)
 
         logger.debug(settings.BASE_DIR)
-        Path(settings.BASE_DIR + "/tmp/restart.txt").touch()
+        full_path_touch = os.path.join(settings.BASE_DIR, "/tmp/restart.txt")
+        logger.debug(full_path_touch)
+        Path(full_path_touch).touch()
 
         return HttpResponse('success')
     # In case we receive an event that's not ping or push
